@@ -1,11 +1,13 @@
 #' Copy and paste MCNP output spectral data for use with \code{mcnp_plot_out_spec()}
 #' @family mcnp tools
 #' @description Provides quick copy-and-paste conversion to data frame.
-#' Conversion is based on the two or three columns with
-#' input energy or output results from MCNP. Energy is expected to be in
-#' bins with maximum energy in MeV in the first column,
-#' the input probability or output mean result for the bin in the
-#' second column, and relative Monte Carlo uncertainty in the third column.
+#' Paste either a source histogram distribution or tally spectrum from MCNP outputs.
+#' Three-column output tally spectra have columns of maximum energy, bin tally, and
+#' relative Monte Carlo uncertainty for the bin tally value.
+#' Four-column  source histogram distributions have columns of entry number, maximum
+#' energy, cumulative probability, and bin probability.
+#' In either case, only the maximum energy and bin probability or result values are used.
+#'
 #' @return spectrum file with maximum energy and MCNP bin value
 #' @examples
 #' # Since this function requires the user
@@ -13,7 +15,7 @@
 #' # is set up to provide data for this purpose.
 #' # To run the example, copy and paste the following
 #' # into an input file and delete the hash tags to run.
-#' # my_hist_data <- scan()
+#' # my_hist_data <- mcnp_scan2spec()
 #' # 0.1000000 3.133122e-05 0.3348260
 #' # 0.4222222 6.731257e-05 0.2017546
 #' # 0.7444444 5.249198e-05 0.4524577
@@ -27,11 +29,11 @@
 #' @export
 mcnp_scan2spec <- function() {
   cat("Use this function to copy, paste and save'\n'")
-  cat("two column input energy data (si sp)'\n'")
+  cat("four column source histogram distribution '\n'")
   cat("or three column binned-by-energy tally results'\n'")
-  cols <- readline("Enter number of columns to enter (2 or 3). ")
-  if (!cols %in% c(2, 3)) {
-    stop("This only works for two or three column energy dists.")
+  cols <- readline("Enter number of columns to enter (3 or 4). ")
+  if (!cols %in% c(3, 4)) {
+    stop("This only works for three or four column energy dists.")
   }
   if (cols == 3) {
     cat("Copy and paste MCNP three column'\n'")
@@ -40,18 +42,21 @@ mcnp_scan2spec <- function() {
     raw_scan <- scan()
     mtrx <- matrix(raw_scan, ncol = 3, byrow = TRUE)
     spec.df <- data.frame(
-      E.avg = mtrx[, 1],
+      E.avg = mtrx[, 1] - c(diff(c(0, mtrx[, 1]))) / 2, # average from Emax
       fraction = mtrx[, 2],
       unc = mtrx[, 3]
     )
   }
-  if (cols == 2) {
-    cat("copy and paste MCNP two column,'\n'")
-    cat("binned-by-energy source input (no header)'\n'")
+  if (cols == 4) {
+    cat("copy and paste MCNP source histogram distribution,'\n'")
+    cat("with no header'\n'")
     cat("then hit [enter]'\n'")
     raw_scan <- scan()
-    mtrx <- matrix(raw_scan, ncol = 2, byrow = TRUE)
-    spec.df <- data.frame(E.avg = mtrx[, 1], prob = mtrx[, 2])
+    mtrx <- matrix(raw_scan, ncol = 4, byrow = TRUE)
+    spec.df <- data.frame(
+      E.avg = mtrx[, 2] - c(diff(c(0, mtrx[, 2]))) / 2, # average from Emax
+      prob = mtrx[, 4]
+    )
   }
   spec.df
 }
